@@ -240,11 +240,11 @@ sub postcode
 
 This is a boolean value showing whether or not the number has been
 ported in from another provider.  It will always evaluate to C<false>
-though unless set by this mthod as there is no way to store the
+though unless set by this method as there is no way to store the
 information on the Magrathea database.
 
 
-        $emerge->ported(true);
+        $emerge->ported(true);      # Assuming true is set to 1
         my $ported = $emerg->ported;
 
 =cut
@@ -253,7 +253,7 @@ sub ported
 {
     my $self = shift;
     my $value : Boolean = shift;
-    my $self->{ported} = $value if defined $value;
+    $self->{ported} = $value if defined $value;
     $value = $self->{ported};
     return $value;
 }
